@@ -13,9 +13,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Shaun McCance  <shaunm@gnome.org>
  */
@@ -54,8 +52,6 @@ enum {
     DOCBOOK_COLUMN_TITLE
 };
 
-static void           yelp_docbook_document_class_init      (YelpDocbookDocumentClass *klass);
-static void           yelp_docbook_document_init            (YelpDocbookDocument      *docbook);
 static void           yelp_docbook_document_dispose         (GObject                  *object);
 static void           yelp_docbook_document_finalize        (GObject                  *object);
 
@@ -95,7 +91,7 @@ static void           transform_error           (YelpTransform        *transform
 static void           transform_finalized       (YelpDocbookDocument  *docbook,
                                                  gpointer              transform);
 
-G_DEFINE_TYPE (YelpDocbookDocument, yelp_docbook_document, YELP_TYPE_DOCUMENT);
+G_DEFINE_TYPE (YelpDocbookDocument, yelp_docbook_document, YELP_TYPE_DOCUMENT)
 #define GET_PRIV(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), YELP_TYPE_DOCBOOK_DOCUMENT, YelpDocbookDocumentPrivate))
 
 typedef struct _YelpDocbookDocumentPrivate  YelpDocbookDocumentPrivate;
@@ -304,6 +300,9 @@ docbook_request_page (YelpDocument         *document,
                               error);
         g_error_free (error);
         break;
+    default:
+        g_assert_not_reached ();
+        break;
     }
 
     g_mutex_unlock (&priv->mutex);
@@ -543,7 +542,6 @@ docbook_walk (YelpDocbookDocument *docbook)
     gchar        autoidstr[20];
     xmlChar     *id = NULL;
     xmlChar     *title = NULL;
-    gchar       *old_page_id = NULL;
     xmlNodePtr   cur, old_cur;
     gboolean chunkQ;
     YelpDocbookDocumentPrivate *priv = GET_PRIV (docbook);
@@ -600,7 +598,6 @@ docbook_walk (YelpDocbookDocument *docbook)
 
         if (priv->cur_page_id)
             yelp_document_set_up_id (document, (gchar *) id, priv->cur_page_id);
-        old_page_id = priv->cur_page_id;
         priv->cur_page_id = g_strdup ((gchar *) id);
     }
 
@@ -688,7 +685,6 @@ static gchar *
 docbook_walk_get_title (YelpDocbookDocument *docbook,
                         xmlNodePtr           cur)
 {
-    YelpDocbookDocumentPrivate *priv = GET_PRIV (docbook);
     gchar *infoname = NULL;
     xmlNodePtr child = NULL;
     xmlNodePtr title = NULL;
@@ -797,7 +793,7 @@ docbook_walk_get_title (YelpDocbookDocument *docbook,
 
     if (title) {
         xmlChar *title_s = xmlNodeGetContent (title);
-        gchar *ret = g_strdup (title_s);
+        gchar *ret = g_strdup ((const gchar *) title_s);
         xmlFree (title_s);
         return ret;
     }
@@ -929,7 +925,6 @@ static void
 docbook_index_node (DocbookIndexData *index)
 {
     xmlNodePtr oldcur, child;
-    YelpDocbookDocumentPrivate *priv = GET_PRIV (index->docbook);
 
     if ((g_str_equal (index->cur->parent->name, "menuchoice") ||
          g_str_equal (index->cur->parent->name, "keycombo")) &&
@@ -937,11 +932,11 @@ docbook_index_node (DocbookIndexData *index)
         g_string_append_c (index->str, ' ');
     }
     if (index->cur->type == XML_TEXT_NODE) {
-        g_string_append (index->str, index->cur->content);
+        g_string_append (index->str, (const gchar *) index->cur->content);
         return;
     }
     if (index->cur->type != XML_ELEMENT_NODE ||
-        g_str_has_suffix (index->cur->name, "info") ||
+        g_str_has_suffix ((const gchar *) index->cur->name, "info") ||
         g_str_equal (index->cur->name, "remark"))
         return;
     oldcur = index->cur;
@@ -970,7 +965,7 @@ docbook_index_chunk (DocbookIndexData *index)
         index->str = g_string_new ("");
     }
 
-    for (child = index->cur->children; child = child->next; child) {
+    for (child = index->cur->children; child; child = child->next) {
         if (docbook_walk_chunkQ (index->docbook, child, index->depth, index->max_depth)) {
             chunks = g_slist_append (chunks, child);
         }
